# Astro Sampler

Sample from distributions commonly used in astronomy.

## Installation

```bash
pip install astrosampler
```

### Dependencies

- `numpy`

## Usage

```python
import astrosampler

# TODO COMING SOON
```
